@@ -1,7 +1,7 @@
 from munin_plugins.utils import *
 
-from munin_plugins.etc.env import CACHE_BOTS
-from munin_plugins.etc.env import MINUTES
+from ..env import CACHE_BOTS
+from ..env import MINUTES
 
 from base import BaseCounter
 
@@ -29,6 +29,14 @@ class BotsCounter(BaseCounter):
               warning=w,
               critical=c,
               )
+    if len(self.counter.items())==0:
+      printer(id='none',
+              value=0,
+              label='none',
+              warning=w,
+              critical=c,
+              )
+      
 
   def update_cache(self):
     self.counter.store_in_cache()
