@@ -4,19 +4,17 @@ import os
 import psutil
 from collections import deque
 
-from munin_plugins.utils import *
-
-from munin_plugins.etc.env import SYSTEM_DEFAULTS
-from munin_plugins.etc.env import SYSTEM_VALUE_CACHE
-from munin_plugins.etc.env import INSTANCES_CACHE
-
-from munin_plugins.plone_analyzers import cpu_usage_snsr
-from munin_plugins.plone_analyzers import memory_snsr
-from munin_plugins.plone_analyzers import connections_snsr
-from munin_plugins.plone_analyzers import swap_snsr
-from munin_plugins.plone_analyzers import storages_snsr
-from munin_plugins.plone_analyzers import io_counters_snsr
-from munin_plugins.plone_analyzers import threads_snsr
+from .utils import *
+from .env import SYSTEM_DEFAULTS
+from .env import SYSTEM_VALUE_CACHE
+from .env import INSTANCES_CACHE
+from .plone_analyzers import cpu_usage_snsr
+from .plone_analyzers import memory_snsr
+from .plone_analyzers import connections_snsr
+from .plone_analyzers import swap_snsr
+from .plone_analyzers import storages_snsr
+from .plone_analyzers import io_counters_snsr
+from .plone_analyzers import threads_snsr
 
 def load_sys(defaults):
   cpath,ctype=SYSTEM_VALUE_CACHE
@@ -35,7 +33,6 @@ def load_sys(defaults):
       system_cache[k]
     except KeyError:  
       system_cache[k]=sys_curr[k]
-
   return system_cache,sys_curr
   
 def find_cfg(command):
@@ -68,7 +65,7 @@ def build_sensor_name(command):
 def load_process():
   cache=CacheDict(INSTANCES_CACHE,def_value=None)
   for pd in psutil.process_iter(): 
-    name=build_sensor_name(pd.cmdline)
+    name=build_sensor_name(pd.cmdline())
     #ppid>1 means that is a child: this check is useful for zeo process 
     if name is not None and pd.ppid>1:
       cache[name]=pd
@@ -102,7 +99,6 @@ def main(argv=None, **kw):
     for name,pd in ps_cache.items():  
       ids="%s_%s"%(name,cl.__name__)
       curr_value=getattr(pd,sensor.proc_mtd,lambda : None)()    
-      prev_value=sensor.getValue(name)
       
       res=sensor.calculate(name,curr_value)
 
@@ -111,13 +107,12 @@ def main(argv=None, **kw):
                 value=res,
                 label=name,
                 draw=graph)
-      elif isinstance(res,list) or isinstance(res,deque):
+      elif isinstance(res,list) or isinstance(res,deque) or isinstance(res,set):
         for fd,row in res:
           printer(id='%s-%s'%(ids,fd),
                   value=row,
                   label='%s %s '%(name,fd),
-                  draw=graph)
-      
+                  draw=graph)        
     if not is_config:        
       sensor.store_in_cache()
 
@@ -126,6 +121,6 @@ def main(argv=None, **kw):
     for k,v in sys_curr.items():    
       sys_prev[k]=v
     #store in the file
-    sys_prev.store_in_cache(clean=True)
-
+    sys_prev.store_in_cache()
+    ps_cache.store_in_cache();
 
